browserui/browser/BrowserAppInc/BrowserGotoPane.h
changeset 10 57d5b8e231c4
parent 0 84ad3b177aa3
child 56 3154c14a33db
--- a/browserui/browser/BrowserAppInc/BrowserGotoPane.h	Mon Mar 30 12:49:49 2009 +0300
+++ b/browserui/browser/BrowserAppInc/BrowserGotoPane.h	Fri May 08 08:18:43 2009 +0300
@@ -20,8 +20,13 @@
 #define WML_GOTO_PANE_BASE_H
 
 // DEFINES
-#define GOTOPANE_POPUPLIST_DISABLE 0
-#define GOTOPANE_POPUPLIST_ENABLE 1
+#ifndef GOTOPANE_POPUPLIST_DISABLE
+#define GOTOPANE_POPUPLIST_DISABLE EFalse
+#endif
+
+#ifndef GOTOPANE_POPUPLIST_ENABLE
+#define GOTOPANE_POPUPLIST_ENABLE ETrue
+#endif
 
 // INCLUDE FILES
 #include <coecntrl.h>
@@ -206,6 +211,28 @@
         */
         void EnableKeyEventHandlerL( TBool aEnable );
 
+        /**
+        * Activate GoTo Pane.
+        */
+        void SetGotoPaneActiveL();
+
+        /**
+        * Activate Search Pane.
+        */
+        void SetSearchPaneActiveL();
+        
+        /**
+        * Check if we are in Goto Mode
+        * @return ETrue if we are in Goto Mode; EFalse otherwise.
+        */
+        inline TBool GotoPaneActive() const { return iGotoPaneActive; }
+        
+        /**
+        * Check if we are in Search Mode
+        * @return ETrue if we are in Search Mode; EFalse otherwise.
+        */
+        inline TBool SearchPaneActive() const { return iSearchPaneActive; }
+        
     public:	// from MCoeControlObserver
 
         /**
@@ -235,6 +262,13 @@
         *
         */
         void HandlePointerEventL(const TPointerEvent& /*aPointerEvent*/);
+        
+        /**
+        * HandleResourceChange
+        * From CCoeControl
+        */
+        void HandleResourceChange(TInt aType);
+        
 
     public:     // from CCoeControl
 
@@ -262,7 +296,13 @@
     public:     // Text manipulation
 
         /**
-        * Lengt of the text in the editor.
+        * Length of the Search text in the editor.
+        * @return The text length
+        */
+        TInt SearchTextLength() const;
+
+        /**
+        * Length of the text in the editor.
         * @since Series60 1.2
         * @return The text length
         */
@@ -284,6 +324,18 @@
         virtual void SetTextL( const TDesC& aTxt );
 
         /**
+        * Set Editor Font Posture to Italic.
+        */
+        void SetTextModeItalicL( );
+        
+        /**
+        * Set Search text.
+        * @param aTxt Text to set
+        * appended if needed.
+        */
+        void SetSearchTextL( const TDesC& aTxt );
+        
+        /**
         * Selects all text in the editor.
         * See CEikEdwin's SelectAllL();
         * @since Series60 1.2
@@ -323,11 +375,6 @@
         * Gives back a pointer to adaptivepopuplist
         */
         CBrowserAdaptiveListPopup* PopupList();
-
-         /**
-        * Handles resource change
-        */        
-		void HandleResourceChange( TInt aType );
 		
          /**
         * Handles the completion of a FEP transaction
@@ -352,6 +399,11 @@
         */
         void ConstructL( const CCoeControl* aParent, TInt aIconBitmapId, TInt aIconMaskId, TBool aPopupListStatus );
 
+        /**
+        * Constructs Search Pane.
+        */
+        void ConstructSearchPaneL();
+        
     protected:  // from CCoeControl
 
         /**
@@ -396,6 +448,12 @@
         // Input frame. Owned.
         CAknInputFrame* iInputFrame;
         
+        // Search Editor. Owned.
+        CEikEdwin* iSearchEditor;  
+        
+        // Search Input frame. Owned.
+        CAknInputFrame* iSearchInputFrame;
+                
         // Observer (may be NULL). Not owned.
         MGotoPaneObserver* iGPObserver;
 		
@@ -404,6 +462,19 @@
 
         /// adaptive popuplist
         CBrowserAdaptiveListPopup* iBAdaptiveListPopup;
+        
+        // Represents Active Editors 
+        TBool iGotoPaneActive;
+        TBool iSearchPaneActive;
+        
+        // Default text in Search Editor.Owned.
+        HBufC* iDefaultSearchText;
+        
+        // Search Input Frame Icon Id, used for tracking the Search Icon Changes.
+        TInt iSearchIconId;
+        
+        // Stores the Search Icon File Path.
+        TFileName iSearchIconFilePath;
     };
 
 #endif